// import classes
import { Component, Input, Output, EventEmitter } from '@angular/core';
import { CategoryService } from '../category.service';
import { Observable } from 'rxjs/Observable';
import { Category } from '../category';

// mark this class as angular component using @Component decorator
@Component({
    selector: 'app-delete-category',
    templateUrl: './delete-category.component.html',
    styleUrls: ['./delete-category.component.css'],
    providers: [CategoryService]
})

// component for deleting a category record
export class DeleteCategoryComponent {

    /*
        @Output will tell the parent component (CategoriesComponent)
        that an event has happened (via .emit(), see readCategories() method below)
    */
    @Output() show_read_categories_event = new EventEmitter();

    // @Input enable getting the category_id from parent component (AppComponent)
    @Input() category_id;

    // initialize category service
    constructor(private categoryService: CategoryService){}

    // user clicks 'yes' button
    deleteCategory(){

        // delete data from database
        this.categoryService.deleteCategory(this.category_id)
            .subscribe(
                 category => {

                    // show an alert to tell the user if category was created or not
                    console.log(category);

                    // go back to list of categories
                    this.readCategories();
                 },
                 error => console.log(error)
             );
    }

    // user clicks the 'read categories' button
    readCategories(){
        this.show_read_categories_event.emit({ title: "Read Categories" });
    }

}
