// import classes
import { Component, OnInit, Input, Output, OnChanges, EventEmitter } from '@angular/core';
import { CategoryService } from '../category.service';
import { Observable } from 'rxjs/Observable';
import { Category } from '../category';

// mark this class as angular component using @Component decorator
@Component({
    selector: 'app-read-one-category',
    templateUrl: './read-one-category.component.html',
    styleUrls: ['./read-one-category.component.css'],
    providers: [CategoryService]
})

// component for reading one category record
export class ReadOneCategoryComponent implements OnChanges {

    /*
        @Output will tell the parent component (CategoriesComponent)
        that an event has happened (via .emit(), see readCategories() method below)
    */
    @Output() show_read_categories_event = new EventEmitter();

    // @Input means it will accept value from parent component (AppComponent)
    @Input() category_id;

    // store one category
    category: Category;

    // initialize category service
    constructor(private categoryService: CategoryService){}

    // user clicks the 'read categories' button
    readCategories(){
        this.show_read_categories_event.emit({ title: "Read Categories" });
    }

    // call the record when 'category_id' was changed
    ngOnChanges(){

        this.categoryService.readOneCategory(this.category_id)
            .subscribe(category => this.category=category);
    }

}
