// import classes
import { Component, OnChanges, Input, Output, EventEmitter } from '@angular/core';
import { FormGroup, FormControl, Validators, FormBuilder } from '@angular/forms';
import { CategoryService } from '../category.service';
import { Observable } from 'rxjs/Observable';
import { Category } from '../category';

// mark this class as angular component using @Component decorator
@Component({
    selector: 'app-update-category',
    templateUrl: './update-category.component.html',
    styleUrls: ['./update-category.component.css'],
    providers: [CategoryService]
})

// component for updating a category record
export class UpdateCategoryComponent implements OnChanges {

    // our angular form
    update_category_form: FormGroup;

    // we let the parent component (CategoriesComponent) know of a triggered event
    @Output() show_read_categories_event = new EventEmitter();

    // we accept category from parent component (CategoriesComponent)
    @Input() category_id;

    // store list of categories
    categories: Category[];

    // initialize category service
    constructor(
        private categoryService: CategoryService,
        private formBuilder: FormBuilder
    ){

        // build angular form
        this.update_category_form = this.formBuilder.group({
            name: ["", Validators.required],
            description: ["", Validators.required]
        });
    }

    // user clicks 'create' button
    updateCategory(){

        // add category_id in the object so it can be updated
        this.update_category_form.value.id = this.category_id;

        // send data to server
        this.categoryService.updateCategory(this.update_category_form.value)
            .subscribe(
                 category => {
                    // show an alert to tell the user if category was created or not
                    console.log(category);

                    // go back to list of categories
                    this.readCategories();
                 },
                 error => console.log(error)
             );
    }

    // user clicks the 'read categories' button
    readCategories(){
        this.show_read_categories_event.emit({ title: "Read Categories" });
    }

    // call the record when 'category_id' was changed
    ngOnChanges(){

        // read one category record
        this.categoryService.readOneCategory(this.category_id)
            .subscribe(category => {

                // put values in the form
                this.update_category_form.patchValue({
                    name: category.name,
                    description: category.description
                });
            });
    }

    // read categories from database
    ngOnInit(){
        this.categoryService.readCategories()
            .subscribe(categories => this.categories=categories);
    }
}
